# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CallType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x43\x61llType.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call*0\n\x08\x43\x61llType\x12\x0e\n\nCT_UNKNOWN\x10\x00\x12\t\n\x05VOICE\x10\x01\x12\t\n\x05VIDEO\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CallType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CALLTYPE._serialized_start=50
  _CALLTYPE._serialized_end=98
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: BasicSearchResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupSearchResult_pb2 as GroupSearchResult__pb2
import UserSearchResult_pb2 as UserSearchResult__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x42\x61sicSearchResponse.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\x1a\x17GroupSearchResult.proto\x1a\x16UserSearchResult.proto\"\x9b\x01\n\x13\x42\x61sicSearchResponse\x12@\n\nuserResult\x18\x01 \x03(\x0b\x32,.AcFunDanmu.Im.Cloud.Search.UserSearchResult\x12\x42\n\x0bgroupResult\x18\x02 \x03(\x0b\x32-.AcFunDanmu.Im.Cloud.Search.GroupSearchResultb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'BasicSearchResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BASICSEARCHRESPONSE._serialized_start=107
  _BASICSEARCHRESPONSE._serialized_end=262
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SystemUser.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10SystemUser.proto\x12\x15\x41\x63\x46unDanmu.Im.Message*9\n\nSystemUser\x12\x16\n\x12kSystemUserInvalid\x10\x00\x12\x13\n\x0eSYSTEM_USER_ID\x10\x90Nb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SystemUser_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SYSTEMUSER._serialized_start=43
  _SYSTEMUSER._serialized_end=100
# @@protoc_insertion_point(module_scope)
